@@ -33,6 +33,7 @@
 #include "bluetooth-chooser-button.h"
 #include "bluetooth-chooser-combo.h"
 #include "bluetooth-client.h"
+#include "bluetooth-utils.h"
 #include "bluetooth-filter-widget.h"
 
 static void dump_selected_device(BluetoothChooser *sel)
@@ -150,7 +151,8 @@ create_phone_dialogue (const char *bdaddr)
 			  G_CALLBACK (is_available_changed), NULL);
 	is_available_changed (G_OBJECT (button), NULL, NULL);
 	gtk_widget_show (button);
-	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), button);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+			    button, TRUE, TRUE, 0);
 
 	return dialog;
 }
@@ -316,7 +318,8 @@ create_combo_dialogue (const char *bdaddr)
 	bluetooth_chooser_start_discovery (BLUETOOTH_CHOOSER (chooser));
 	gtk_container_set_border_width(GTK_CONTAINER(selector), 5);
 	gtk_widget_show(selector);
-	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))), selector);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+			    selector, TRUE, TRUE, 0);
 
 	g_signal_connect (G_OBJECT (dialog), "response",
 			  G_CALLBACK (response_cb), selector);
@@ -331,7 +334,7 @@ create_filter_dialogue (void)
 
 	dialog = create_dialogue ("Add a Device");
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_show (hbox);
 
 	selector = g_object_new (BLUETOOTH_TYPE_CHOOSER,
@@ -345,7 +348,7 @@ create_filter_dialogue (void)
 		     NULL);
 	gtk_box_pack_start (GTK_BOX (hbox), selector, TRUE, TRUE, 6);
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 	filter = bluetooth_filter_widget_new ();
@@ -365,7 +368,8 @@ create_filter_dialogue (void)
 			 G_CALLBACK(device_type_filter_selected_cb), dialog);
 	g_signal_connect(selector, "notify::device-category-filter",
 			 G_CALLBACK(device_category_filter_selected_cb), dialog);
-	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))), hbox);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+			    hbox, TRUE, TRUE, 0);
 	bluetooth_chooser_start_discovery (BLUETOOTH_CHOOSER (selector));
 
 	g_signal_connect (G_OBJECT (dialog), "response",
