@@ -26,7 +26,7 @@
 #endif
 
 #include <glib/gi18n-lib.h>
-#include <libgnome-control-center/cc-shell.h>
+#include "cut-n-paste/cc-shell.h"
 
 #include "cc-bluetooth-panel.h"
 
@@ -44,10 +44,9 @@ G_DEFINE_DYNAMIC_TYPE (CcBluetoothPanel, cc_bluetooth_panel, CC_TYPE_PANEL)
 
 #define WID(s) GTK_WIDGET (gtk_builder_get_object (self->priv->builder, s))
 
-#define GNOMECC			"gnome-control-center"
-#define KEYBOARD_PREFS		GNOMECC " keyboard"
-#define MOUSE_PREFS		GNOMECC " mouse"
-#define SOUND_PREFS		GNOMECC " sound"
+#define KEYBOARD_PREFS		"keyboard"
+#define MOUSE_PREFS		"mouse"
+#define SOUND_PREFS		"sound"
 #define WIZARD			"bluetooth-wizard"
 
 struct CcBluetoothPanelPrivate {
@@ -309,7 +308,7 @@ cc_bluetooth_panel_update_properties (CcBluetoothPanel *self)
 			guint i;
 
 			uuids = (const char **) g_value_get_boxed (&value);
-			for (i = 0; uuids[i] != NULL; i++) {
+			for (i = 0; uuids && uuids[i] != NULL; i++) {
 				if (g_str_equal (uuids[i], "OBEXObjectPush"))
 					gtk_widget_show (WID ("send_box"));
 				else if (g_str_equal (uuids[i], "OBEXFileTransfer"))
@@ -432,24 +431,42 @@ cc_bluetooth_panel_update_power (CcBluetoothPanel *self)
 }
 
 static void
+switch_panel (CcBluetoothPanel *self,
+	      const char       *panel)
+{
+  CcShell *shell;
+  GError *error = NULL;
+
+  shell = cc_panel_get_shell (CC_PANEL (self));
+  if (cc_shell_set_active_panel_from_id (shell, panel, NULL, &error) == FALSE)
+    {
+      g_warning ("Failed to activate Region panel: %s", error->message);
+      g_error_free (error);
+    }
+}
+
+static gboolean
 keyboard_callback (GtkButton        *button,
 		   CcBluetoothPanel *self)
 {
-	launch_command (KEYBOARD_PREFS);
+	switch_panel (self, KEYBOARD_PREFS);
+	return TRUE;
 }
 
-static void
+static gboolean
 mouse_callback (GtkButton        *button,
 		CcBluetoothPanel *self)
 {
-	launch_command (MOUSE_PREFS);
+	switch_panel (self, MOUSE_PREFS);
+	return TRUE;
 }
 
-static void
+static gboolean
 sound_callback (GtkButton        *button,
 		CcBluetoothPanel *self)
 {
-	launch_command (SOUND_PREFS);
+	switch_panel (self, SOUND_PREFS);
+	return TRUE;
 }
 
 static void
@@ -635,7 +652,7 @@ cc_bluetooth_panel_init (CcBluetoothPanel *self)
 		return;
 	}
 
-	widget = WID ("vbox");
+	widget = WID ("grid");
 	gtk_widget_reparent (widget, GTK_WIDGET (self));
 
 	/* Overall device state */
@@ -694,11 +711,11 @@ cc_bluetooth_panel_init (CcBluetoothPanel *self)
 
 	/* Set the initial state of the properties */
 	cc_bluetooth_panel_update_properties (self);
-	g_signal_connect (G_OBJECT (WID ("mouse_button")), "clicked",
+	g_signal_connect (G_OBJECT (WID ("mouse_link")), "activate-link",
 			  G_CALLBACK (mouse_callback), self);
-	g_signal_connect (G_OBJECT (WID ("keyboard_button")), "clicked",
+	g_signal_connect (G_OBJECT (WID ("keyboard_link")), "activate-link",
 			  G_CALLBACK (keyboard_callback), self);
-	g_signal_connect (G_OBJECT (WID ("sound_button")), "clicked",
+	g_signal_connect (G_OBJECT (WID ("sound_link")), "activate-link",
 			  G_CALLBACK (sound_callback), self);
 	g_signal_connect (G_OBJECT (WID ("browse_button")), "clicked",
 			  G_CALLBACK (browse_callback), self);
